// Packet.h : header file
//
// Copyright(C) 2008 ubisys technologies GmbH, Duesseldorf, Germany.
// All rights reserved.
//
// www.ubisys.de
// support@ubisys.de
//
// THIS SOURCE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, 
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF 
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
//
// IN NO EVENT SHALL UBISYS TECHNOLOGIES BE LIABLE FOR ANY CLAIM, DAMAGES OR
// OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
// ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOURCE CODE OR THE USE OR
// OTHER DEALINGS IN THE SOURCE CODE.
//
// Part of the Compact15.4(TM) class library
//
// Adds the ability to dump CPacket objects

#include <cassert>
#include "DebugUnit.h"
#include "Packet.h"

/////////////////////////////////////////////////////////////////////////////
// CPacketData

#ifdef _DEBUG

void CPacketData::Dump(const size_type nStart) const
{
	TRACE6(" [ %08x, r = %u, u = %u(%u), a = %u/%u ]", 
		reinterpret_cast<unsigned int>(this), m_nReference, GetSize() - nStart, 
		GetSize(), m_nOffset, m_nCapacity - m_nOffset - m_nSize);
	
	for (size_type i = nStart; i < GetSize(); i++)
		TRACE1(" %02x", *(static_cast<const unsigned char *>(GetData()) + i));

	TRACE0("\r\n");
}

#endif


/////////////////////////////////////////////////////////////////////////////
// CPacket

#ifdef _DEBUG

void CPacket::Dump(const char *const pszMessage, 
	const CPacketData::size_type nStart) const
{
	if (pszMessage)
		TRACE1("%hs", pszMessage);

	if (m_pData)
		m_pData->Dump(nStart);
	else
		TRACE0(" <empty>\r\n");
}

#endif
